@@ -6,13 +6,12 @@
 
   ########  if the pick has no station name it must be bpgus.  SEE EMPTYPickfile
   YPX=P$STAS
-  w = which(YPX$name == "")
+  w = which(YPX$name == "" | is.na(YPX$name) )
 
   if(length(w)<1) return(P)
   
-  Z = data.frame(YPX, stringsAsFactors = FALSE)
-
-  Y = Z[-w,  ]
+  
+  Y = deleteWPX(YPX, w)
 
   
   P$STAS =  as.list(Y)
